"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var tools_1 = require("./tools");
var pcf_1 = require("./pcf");
var Flow = /** @class */ (function () {
    function Flow(triple) {
        this.triple = triple;
    }
    Flow.prototype._getTmpFileBase = function (file) {
        var builddir = path.dirname(file);
        var filename = path.basename(file);
        var parts = filename.split('.');
        if (parts.length > 1) {
            parts.pop();
        }
        return path.join(builddir, parts.join('.'));
    };
    Flow.prototype.flow = function (input, output, top, pcf) {
        var tmpBase = this._getTmpFileBase(output);
        var synth_output = tmpBase + '.json';
        var pnr_output = tmpBase + '.asc';
        if (pcf instanceof pcf_1.Pcf) {
            var pcf_output = tmpBase + '.pcf';
            pcf.write(pcf_output);
            pcf = pcf_output;
        }
        this.synth(input, synth_output, top);
        this.pnr(synth_output, pnr_output, pcf);
        this.pack(pnr_output, output);
    };
    Flow.prototype.synth = function (input, output, top) {
        if (!this._synth) {
            this._synth = new tools_1.Synth(this.triple);
        }
        this._synth.synth(input, output, top);
    };
    Flow.prototype.pnr = function (input, output, pcf) {
        if (!this._pnr) {
            this._pnr = new tools_1.Pnr(this.triple);
        }
        this._pnr.pnr(input, output, pcf);
    };
    Flow.prototype.pack = function (input, output) {
        if (!this._pack) {
            this._pack = new tools_1.Pack(this.triple);
        }
        this._pack.pack(input, output);
    };
    Flow.prototype.prog = function (input) {
        if (!this._prog) {
            this._prog = new tools_1.Prog(this.triple);
        }
        this._prog.prog(input);
    };
    Flow.prototype.time = function (input) {
        if (!this._time) {
            this._time = new tools_1.Time(this.triple);
        }
        this._time.time(input);
    };
    return Flow;
}());
exports.Flow = Flow;
